@@ -2,6 +2,8 @@ import re
 import time
 from enum import Enum
 
+from anadroid.utils.Utils import loge
+
 
 class DEVICE_STATE_ENFORCE(Enum):
     IDLE = "Idle"
@@ -61,18 +63,18 @@ class DeviceState(object):
 
     def get_screen_brightness(self):
         res = self.device.execute_command("settings get system screen_brightness", shell=True)
-        if res.validate(Exception("Unable to obtain screen brightness")):
+        if res.validate(("Unable to obtain screen brightness")):
             return int(re.search(r"[0-9]+", res.output).group())
 
     def get_screen_always_on(self):
         res = self.device.execute_command("settings get global stay_on_while_plugged_in", shell=True)
-        if res.validate(Exception("Unable to obtain screen always_on val")):
+        if res.validate(("Unable to obtain screen always_on val")):
             val = int(re.search(r"[0-9]+", res.output).group())
             return 0 if val == 0 else 1
 
     def get_screen_auto_rotate(self):
         res = self.device.execute_command("settings get system accelerometer_rotation", shell=True)
-        if res.validate(Exception("Unable to obtain screen auto rotate val")):
+        if res.validate(("Unable to obtain screen auto rotate val")):
             return int(re.search(r"[0-9]+", res.output).group())
 
     def get_screen_orientation(self):
@@ -82,12 +84,12 @@ class DeviceState(object):
 
     def get_bluetooth_state(self):
         res = self.device.execute_command("settings get global bluetooth_on", shell=True)
-        if res.validate(Exception("Unable to obtain bluetooth state")):
+        if res.validate(("Unable to obtain bluetooth state")):
             return int(re.search(r"[0-1]", res.output).group())
 
     def get_wifi_state(self):
         res = self.device.execute_command("settings get global wifi_on", shell=True)
-        if res.validate(Exception("Unable to obtain wifi state")):
+        if res.validate(("Unable to obtain wifi state")):
             return int(re.search(r"[0-1]", res.output).group())
 
     def get_hotspot_state(self):
@@ -100,23 +102,23 @@ class DeviceState(object):
 
     def get_gps_state(self):
         res = self.device.execute_command("settings get secure location_providers_allowed | grep \"gps\"", shell=True)
-        if res.validate(Exception("Unable to obtain gps state")):
+        if res.validate(("Unable to obtain gps state")):
             return 1 if "gps" in res.output else 0
 
     def get_nfc_state(self):
         res = self.device.execute_command("dumpsys nfc | grep \"mState=on\"", shell=True)
-        if res.validate(Exception("Unable to obtain nfc state")):
+        if res.validate("Unable to obtain nfc state"):
             return 1 if "on" in res.output else 0
 
     def get_mobile_data_state(self):
         res = self.device.execute_command("settings get global  device_provisioning_mobile_data", shell=True)
-        if res.validate(Exception("Unable to obtain mobile data state")):
+        if res.validate(("Unable to obtain mobile data state")):
             return 1 if "1" in res.output else 0
 
     def get_speakers_state(self):
         # ring and notifications vol?
         res = self.device.execute_command("dumpsys audio | grep \"STREAM_SYSTEM:\" -A 1", shell=True)
-        if res.validate(Exception("unable to obtain speakers state ")):
+        if res.validate(("unable to obtain speakers state ")):
             return 1 if "false" in res.output.lower() else 0
 
     # setters
@@ -131,7 +133,7 @@ class DeviceState(object):
 
     def set_screen_brightness(self, value=0):
         res = self.device.execute_command(f"settings put system screen_brightness {value}", shell=True)
-        res.validate(Exception("unable to set brightness value of %d " % value))
+        res.validate(("unable to set brightness value of %d " % value))
         self.screen_brightness = value
 
     def set_screen_always_on_while_plugged(self, value=0):
@@ -141,7 +143,7 @@ class DeviceState(object):
             res = self.device.execute_command(f"svc power stayon true", shell=True)
         else:
             res = self.device.execute_command(f"svc power stayon false", shell=True)
-        res.validate(Exception("unable to turn on/off screen always on "))
+        res.validate(("unable to turn on/off screen always on "))
         self.screen_always_on = value
 
     def set_screen_auto_rotate(self, value=0):
@@ -150,7 +152,7 @@ class DeviceState(object):
         else:
             # adb shell settings put system accelerometer_rotation 0  #disable auto-rotate
             res = self.device.execute_command(f" settings put system accelerometer_rotation 0", shell=True)
-        res.validate(Exception("unable to turn on/off screen autorotate"))
+        res.validate(("unable to turn on/off screen autorotate"))
         self.screen_auto_rotate = value
 
     def set_screen_orientation(self, value=0):
@@ -161,7 +163,7 @@ class DeviceState(object):
             self.set_screen_auto_rotate(0)
             time.sleep(2)
         res = self.device.execute_command(f"settings put system user_rotation {value}", shell=True)
-        res.validate(Exception(f"unable to rotate screen to val {value}"))
+        res.validate((f"unable to rotate screen to val {value}"))
         self.screen_orientation = value
         if is_auto_rotating == 1:
             self.set_screen_auto_rotate(1)
@@ -175,9 +177,9 @@ class DeviceState(object):
                 res = self.device.execute_root_command(f"service call bluetooth_manager 6")
             else:
                 res = self.device.execute_root_command(f"pm disable com.android.bluetooth")
-            res.validate(Exception("Unable to change bluetooth state"))
+            res.validate(("Unable to change bluetooth state"))
         else:
-            raise Exception("changing bluetooth state is only available for rooted devices")
+             loge("changing bluetooth state is only available for rooted devices")
         self.bluetooth = value
 
     def set_gps_state(self, value=0):
@@ -186,7 +188,7 @@ class DeviceState(object):
             res = self.device.execute_root_command(f"settings put secure location_providers_allowed +gps")
         else:
             res = self.device.execute_root_command(f"settings put secure location_providers_allowed -gps")
-        res.validate(Exception("Unable to change gps state"))
+        res.validate(("Unable to change gps state"))
         self.gps = value
 
     def set_nfc_state(self, value=0):
@@ -194,13 +196,13 @@ class DeviceState(object):
             res = self.device.execute_root_command(f"svc nfc enable")
         else:
             res = self.device.execute_root_command(f"svc nfc disable")
-        res.validate(Exception("Unable to change nfc state"))
+        res.validate(("Unable to change nfc state"))
         self.nfc_state = value
 
     def change_speaker_state(self, value=0):
         if value != self.speakers_state:
             res = self.device.execute_command(f'input keyevent 164', shell=True)
-            res.validate(Exception("Unable to change speakers state"))
+            res.validate(("Unable to change speakers state"))
             self.speakers_state = 0 if value == 0 else 1
 
     def set_hotspot_state(self, value=0):
@@ -211,16 +213,16 @@ class DeviceState(object):
             res = self.device.execute_root_command(f"svc data enable")
         else:
             res = self.device.execute_root_command(f"svc data disable")
-        res.validate(Exception("Unable to change nfc state"))
-        self.nfc_state = value
+        res.validate(("Unable to change nfc state"))
+        self.mobile_data_state = value
 
     def set_wifi_state(self, value=0):
         if value == 1:
             res = self.device.execute_root_command(f"svc wifi enable")
         else:
             res = self.device.execute_root_command(f"svc wifi disable")
-        res.validate(Exception("Unable to change wifi state"))
-        self.nfc_state = value
+        res.validate(("Unable to change wifi state"))
+        self.wifi = value
 
     def get_states_from_permission(self, perm_id):
         if perm_id in PERMISSIONS_TO_STATE:
@@ -284,4 +286,4 @@ class DeviceState(object):
         # elif key == 'hotspot_state':
         #    self.set_hotspot_state(val)
         else:
-            raise Exception(f"{key} not implemented")
+            raise Exception(f"{key} not implemented")
\ No newline at end of file
